# Application Rationalization
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/application-rationalization#overview)
  * [What is Application Rationalization?](https://help.sap.com/docs/leanix/ea/application-rationalization#what-is-application-rationalization?)
  * [Why Is Application Rationalization Relevant?](https://help.sap.com/docs/leanix/ea/application-rationalization#why-is-application-rationalization-relevant?)
  * [What Are the Benefits of Application Rationalization?](https://help.sap.com/docs/leanix/ea/application-rationalization#what-are-the-benefits-of-application-rationalization?)
  * [Before You Start](https://help.sap.com/docs/leanix/ea/application-rationalization#before-you-start)
  * [Step-by-Step Guide](https://help.sap.com/docs/leanix/ea/application-rationalization#step-by-step-guide)
  * [Related Resources](https://help.sap.com/docs/leanix/ea/application-rationalization#related-resources)


Application rationalization reduces costs, eliminates redundancies, and improves efficiency. Optimize your application landscape with this step-by-step approach.
